@@ -671,30 +671,37 @@ END:VCARD
                 std::fs::read_to_string(format!("resources/responses/{:03}.xml", num + 1)).unwrap();
             let mut output_token = Tokenizer::new(test.as_bytes());
             let mut expected_token = Tokenizer::new(xml.as_bytes());
+            let mut output_tokens = Vec::new();
+            let mut expected_tokens = Vec::new();
 
-            loop {
-                let mut output = output_token.token().unwrap();
-                let mut expected = expected_token.token().unwrap();
-
-                for token in [&mut output, &mut expected] {
-                    if let Token::Bytes(text) = token {
-                        // Remove '\r'
-                        *text = text
-                            .iter()
-                            .copied()
-                            .filter(|&c| c != b'\r')
-                            .collect::<Vec<_>>()
-                            .into();
+            for (tokens, tokenizer) in [
+                (&mut output_tokens, &mut output_token),
+                (&mut expected_tokens, &mut expected_token),
+            ] {
+                while let Ok(token) = tokenizer.token() {
+                    if token == Token::Eof {
+                        break;
+                    }
+                    match (tokens.last_mut(), token) {
+                        (Some(Token::Text(text)), Token::Text(new_text)) => {
+                            *text = format!("{}{}", text, new_text).into();
+                        }
+                        (_, element) => {
+                            tokens.push(element.into_owned());
+                        }
                     }
                 }
+            }
 
+            assert!(!output_tokens.is_empty());
+            assert!(!expected_tokens.is_empty());
+            assert_eq!(output_tokens.len(), expected_tokens.len());
+
+            for (output, expected) in output_tokens.iter().zip(expected_tokens.iter()) {
                 if output != expected {
                     eprintln!("{test}");
                 }
                 assert_eq!(output, expected, "failed for {:03}.xml", num + 1);
-                if output == Token::Eof {
-                    break;
-                }
             }
         }
     }
