@@ -18,7 +18,7 @@ use serde::{
 };
 use std::{collections::hash_map::Entry, fmt, str::FromStr};
 use store::{
-    U64_LEN,
+    U32_LEN, U64_LEN,
     backend::MAX_TOKEN_LENGTH,
     write::{BatchBuilder, DirectoryClass},
 };
@@ -238,13 +238,11 @@ impl Principal {
             } else {
                 None
             }
-        }) {
-            if let Some(idx) = permissions
-                .iter_mut()
-                .position(|p| p.permission == permission && p.grant == grant)
-            {
-                permissions.swap_remove(idx);
-            }
+        }) && let Some(idx) = permissions
+            .iter_mut()
+            .position(|p| p.permission == permission && p.grant == grant)
+        {
+            permissions.swap_remove(idx);
         }
     }
 
@@ -260,7 +258,11 @@ impl Principal {
         }
     }
 
-    pub fn update_external(&mut self, mut external: Principal) -> Vec<PrincipalUpdate> {
+    pub fn update_external(
+        &mut self,
+        mut external: Principal,
+        overwrite_emails: bool,
+    ) -> Vec<PrincipalUpdate> {
         let mut updates = Vec::new();
 
         // Add external members
@@ -270,10 +272,10 @@ impl Principal {
         }
 
         // If the principal has no roles, take the ones from the external principal
-        if let Some(roles) = external.roles_mut().filter(|s| !s.is_empty()) {
-            if self.roles().is_empty() {
-                self.data.push(PrincipalData::Roles(std::mem::take(roles)));
-            }
+        if let Some(roles) = external.roles_mut().filter(|s| !s.is_empty())
+            && self.roles().is_empty()
+        {
+            self.data.push(PrincipalData::Roles(std::mem::take(roles)));
         }
 
         if external.description.as_ref().is_some_and(|v| !v.is_empty())
@@ -286,16 +288,34 @@ impl Principal {
             ));
         }
 
-        for (name, field, external_field) in [
-            (PrincipalField::Secrets, &mut self.secrets, external.secrets),
-            (PrincipalField::Emails, &mut self.emails, external.emails),
-        ] {
-            if !external_field.is_empty() && &external_field != field {
-                *field = external_field;
+        if !external.secrets.is_empty() && external.secrets != self.secrets {
+            self.secrets = external.secrets;
+            updates.push(PrincipalUpdate::set(
+                PrincipalField::Secrets,
+                PrincipalValue::StringList(self.secrets.clone()),
+            ));
+        }
+
+        if !external.emails.is_empty() && external.emails != self.emails {
+            if overwrite_emails {
+                self.emails = external.emails;
                 updates.push(PrincipalUpdate::set(
-                    name,
-                    PrincipalValue::StringList(field.clone()),
+                    PrincipalField::Emails,
+                    PrincipalValue::StringList(self.emails.clone()),
                 ));
+            } else {
+                // Missing emails are appended to avoid overwriting locally defined aliases
+                // This means that old email addresses need to be deleted either manually or using the API
+                for email in external.emails {
+                    let email = email.to_lowercase();
+                    if !self.emails.contains(&email) {
+                        updates.push(PrincipalUpdate::add_item(
+                            PrincipalField::Emails,
+                            PrincipalValue::String(email.clone()),
+                        ));
+                        self.emails.push(email);
+                    }
+                }
             }
         }
 
@@ -310,6 +330,28 @@ impl Principal {
         updates
     }
 
+    pub fn object_size(&self) -> usize {
+        self.name.len()
+            + self.description.as_ref().map_or(0, |d| d.len())
+            + self.secrets.iter().map(|s| s.len()).sum::<usize>()
+            + self.emails.iter().map(|e| e.len()).sum::<usize>()
+            + self
+                .data
+                .iter()
+                .map(|d| match d {
+                    PrincipalData::MemberOf(items)
+                    | PrincipalData::Roles(items)
+                    | PrincipalData::Lists(items) => items.len() * U32_LEN,
+                    PrincipalData::Permissions(items) => items.len() * U32_LEN,
+                    PrincipalData::ExternalMembers(items) | PrincipalData::Urls(items) => {
+                        items.iter().map(|s| s.len()).sum::<usize>()
+                    }
+                    PrincipalData::PrincipalQuota(items) => items.len() * U32_LEN,
+                    PrincipalData::Picture(value) | PrincipalData::Locale(value) => value.len(),
+                })
+                .sum::<usize>()
+    }
+
     pub fn fallback_admin(fallback_pass: impl Into<String>) -> Self {
         Principal {
             id: FALLBACK_ADMIN_ID,
