@@ -4,15 +4,14 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use common::storage::index::{IndexValue, IndexableAndSerializableObject, IndexableObject};
-use jmap_proto::types::collection::SyncCollection;
-
 use super::{ArchivedIdentity, Identity};
+use common::storage::index::{IndexValue, IndexableAndSerializableObject, IndexableObject};
+use types::collection::SyncCollection;
 
 impl IndexableObject for Identity {
     fn index_values(&self) -> impl Iterator<Item = IndexValue<'_>> {
         [IndexValue::LogItem {
-            sync_collection: SyncCollection::Identity.into(),
+            sync_collection: SyncCollection::Identity,
             prefix: None,
         }]
         .into_iter()
@@ -22,7 +21,7 @@ impl IndexableObject for Identity {
 impl IndexableObject for &ArchivedIdentity {
     fn index_values(&self) -> impl Iterator<Item = IndexValue<'_>> {
         [IndexValue::LogItem {
-            sync_collection: SyncCollection::Identity.into(),
+            sync_collection: SyncCollection::Identity,
             prefix: None,
         }]
         .into_iter()
