@@ -4,20 +4,19 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use common::storage::index::{IndexValue, IndexableAndSerializableObject, IndexableObject};
-use jmap_proto::types::{collection::SyncCollection, property::Property};
-
 use super::{ArchivedSieveScript, SieveScript};
+use common::storage::index::{IndexValue, IndexableAndSerializableObject, IndexableObject};
+use types::{collection::SyncCollection, field::SieveField};
 
 impl IndexableObject for SieveScript {
     fn index_values(&self) -> impl Iterator<Item = IndexValue<'_>> {
         [
             IndexValue::Index {
-                field: Property::Name.into(),
+                field: SieveField::Name.into(),
                 value: self.name.as_str().to_lowercase().into(),
             },
             IndexValue::Index {
-                field: Property::IsActive.into(),
+                field: SieveField::IsActive.into(),
                 value: if self.is_active { &[1u8] } else { &[0u8] }
                     .as_slice()
                     .into(),
@@ -26,7 +25,7 @@ impl IndexableObject for SieveScript {
                 value: self.blob_hash.clone(),
             },
             IndexValue::LogItem {
-                sync_collection: SyncCollection::SieveScript.into(),
+                sync_collection: SyncCollection::SieveScript,
                 prefix: None,
             },
             IndexValue::Quota { used: self.size },
@@ -45,11 +44,11 @@ impl IndexableObject for &ArchivedSieveScript {
     fn index_values(&self) -> impl Iterator<Item = IndexValue<'_>> {
         [
             IndexValue::Index {
-                field: Property::Name.into(),
+                field: SieveField::Name.into(),
                 value: self.name.to_lowercase().into(),
             },
             IndexValue::Index {
-                field: Property::IsActive.into(),
+                field: SieveField::IsActive.into(),
                 value: if self.is_active { &[1u8] } else { &[0u8] }
                     .as_slice()
                     .into(),
@@ -58,7 +57,7 @@ impl IndexableObject for &ArchivedSieveScript {
                 value: (&self.blob_hash).into(),
             },
             IndexValue::LogItem {
-                sync_collection: SyncCollection::SieveScript.into(),
+                sync_collection: SyncCollection::SieveScript,
                 prefix: None,
             },
             IndexValue::Quota {
