@@ -4,36 +4,35 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use common::storage::index::{IndexValue, IndexableAndSerializableObject, IndexableObject};
-use jmap_proto::types::{collection::SyncCollection, property::Property};
-
 use super::{ArchivedEmailSubmission, EmailSubmission};
+use common::storage::index::{IndexValue, IndexableAndSerializableObject, IndexableObject};
+use types::{collection::SyncCollection, field::EmailSubmissionField};
 
 impl IndexableObject for EmailSubmission {
     fn index_values(&self) -> impl Iterator<Item = IndexValue<'_>> {
         [
             IndexValue::Index {
-                field: Property::UndoStatus.into(),
+                field: EmailSubmissionField::UndoStatus.into(),
                 value: self.undo_status.as_index().into(),
             },
             IndexValue::Index {
-                field: Property::EmailId.into(),
+                field: EmailSubmissionField::EmailId.into(),
                 value: self.email_id.into(),
             },
             IndexValue::Index {
-                field: Property::ThreadId.into(),
+                field: EmailSubmissionField::ThreadId.into(),
                 value: self.thread_id.into(),
             },
             IndexValue::Index {
-                field: Property::IdentityId.into(),
+                field: EmailSubmissionField::IdentityId.into(),
                 value: self.identity_id.into(),
             },
             IndexValue::Index {
-                field: Property::SendAt.into(),
+                field: EmailSubmissionField::SendAt.into(),
                 value: self.send_at.into(),
             },
             IndexValue::LogItem {
-                sync_collection: SyncCollection::EmailSubmission.into(),
+                sync_collection: SyncCollection::EmailSubmission,
                 prefix: None,
             },
         ]
@@ -45,27 +44,27 @@ impl IndexableObject for &ArchivedEmailSubmission {
     fn index_values(&self) -> impl Iterator<Item = IndexValue<'_>> {
         [
             IndexValue::Index {
-                field: Property::UndoStatus.into(),
+                field: EmailSubmissionField::UndoStatus.into(),
                 value: self.undo_status.as_index().into(),
             },
             IndexValue::Index {
-                field: Property::EmailId.into(),
+                field: EmailSubmissionField::EmailId.into(),
                 value: self.email_id.into(),
             },
             IndexValue::Index {
-                field: Property::ThreadId.into(),
+                field: EmailSubmissionField::ThreadId.into(),
                 value: self.thread_id.into(),
             },
             IndexValue::Index {
-                field: Property::IdentityId.into(),
+                field: EmailSubmissionField::IdentityId.into(),
                 value: self.identity_id.into(),
             },
             IndexValue::Index {
-                field: Property::SendAt.into(),
+                field: EmailSubmissionField::SendAt.into(),
                 value: self.send_at.into(),
             },
             IndexValue::LogItem {
-                sync_collection: SyncCollection::EmailSubmission.into(),
+                sync_collection: SyncCollection::EmailSubmission,
                 prefix: None,
             },
         ]
