@@ -10,7 +10,7 @@ pub mod storage;
 use calcard::vcard::VCard;
 use common::DavName;
 use dav_proto::schema::request::DeadProperty;
-use jmap_proto::types::{acl::Acl, value::AclGrant};
+use types::acl::{Acl, AclGrant};
 
 #[derive(
     rkyv::Archive, rkyv::Deserialize, rkyv::Serialize, Debug, Default, Clone, PartialEq, Eq,
