@@ -49,13 +49,11 @@ use jmap::{
     blob::{download::BlobDownload, upload::BlobUpload},
     websocket::upgrade::WebSocketUpgrade,
 };
-use jmap_proto::{
-    request::{Request, capability::Session},
-    types::{blob::BlobId, id::Id},
-};
-use std::{net::IpAddr, sync::Arc};
+use jmap_proto::request::{Request, capability::Session};
+use std::{net::IpAddr, str::FromStr, sync::Arc};
 use store::dispatch::lookup::KeyValue;
 use trc::SecurityEvent;
+use types::{blob::BlobId, id::Id};
 use utils::url_params::UrlParams;
 
 pub trait ParseHttp: Sync + Send {
@@ -95,7 +93,7 @@ impl ParseHttp for Server {
                         let (_in_flight, access_token) =
                             self.authenticate_headers(&req, &session, false).await?;
 
-                        let request = fetch_body(
+                        let bytes = fetch_body(
                             &mut req,
                             if !access_token.has_permission(Permission::UnlimitedUploads) {
                                 self.core.jmap.upload_max_size
@@ -105,17 +103,18 @@ impl ParseHttp for Server {
                             session.session_id,
                         )
                         .await
-                        .ok_or_else(|| trc::LimitEvent::SizeRequest.into_err())
-                        .and_then(|bytes| {
-                            Request::parse(
-                                &bytes,
-                                self.core.jmap.request_max_calls,
-                                self.core.jmap.request_max_size,
-                            )
-                        })?;
+                        .ok_or_else(|| trc::LimitEvent::SizeRequest.into_err())?;
 
                         return Ok(self
-                            .handle_jmap_request(request, access_token, &session)
+                            .handle_jmap_request(
+                                Request::parse(
+                                    &bytes,
+                                    self.core.jmap.request_max_calls,
+                                    self.core.jmap.request_max_size,
+                                )?,
+                                access_token,
+                                &session,
+                            )
                             .await
                             .into_http_response());
                     }
@@ -125,7 +124,7 @@ impl ParseHttp for Server {
                             self.authenticate_headers(&req, &session, false).await?;
 
                         if let (Some(_), Some(blob_id), Some(name)) = (
-                            path.next().and_then(|p| Id::from_bytes(p.as_bytes())),
+                            path.next().and_then(|p| Id::from_str(p).ok()),
                             path.next().and_then(BlobId::from_base32),
                             path.next(),
                         ) {
@@ -153,9 +152,7 @@ impl ParseHttp for Server {
                         let (_in_flight, access_token) =
                             self.authenticate_headers(&req, &session, false).await?;
 
-                        if let Some(account_id) =
-                            path.next().and_then(|p| Id::from_bytes(p.as_bytes()))
-                        {
+                        if let Some(account_id) = path.next().and_then(|p| Id::from_str(p).ok()) {
                             return match fetch_body(
                                 &mut req,
                                 if !access_token.has_permission(Permission::UnlimitedUploads) {
