@@ -7,7 +7,7 @@
 pub mod error;
 pub mod method;
 pub mod object;
-pub mod parser;
+pub mod references;
 pub mod request;
 pub mod response;
 pub mod types;
