@@ -4,13 +4,9 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use std::fmt::Display;
+use std::{fmt::Display, str::FromStr};
 
-use store::SerializeInfallible;
-
-use crate::parser::{JsonObjectParser, json::Parser};
-
-#[derive(Debug, Default, Clone, PartialEq, Eq, Hash)]
+#[derive(Debug, Default, Clone, PartialEq, Eq, Hash, PartialOrd, Ord)]
 pub struct UTCDate {
     pub year: u16,
     pub month: u8,
@@ -23,11 +19,10 @@ pub struct UTCDate {
     pub tz_minute: u8,
 }
 
-impl JsonObjectParser for UTCDate {
-    fn parse(parser: &mut Parser<'_>) -> trc::Result<Self>
-    where
-        Self: Sized,
-    {
+impl FromStr for UTCDate {
+    type Err = ();
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
         // 2004 - 06 - 28 T 23 : 43 : 45 . 000 Z
         // 1969 - 02 - 13 T 23 : 32 : 00 - 03 : 30
         //   0     1    2    3    4    5    6    7
@@ -47,7 +42,7 @@ impl JsonObjectParser for UTCDate {
         let mut skip_digits = false;
         let mut is_plus = true;
 
-        while let Some(ch) = parser.next_unescaped()? {
+        for ch in s.as_bytes() {
             match ch {
                 b'0'..=b'9' => {
                     if !skip_digits {
@@ -119,7 +114,7 @@ impl JsonObjectParser for UTCDate {
                 tz_before_gmt: !is_plus,
             })
         } else {
-            Err(parser.error_value())
+            Err(())
         }
     }
 }
@@ -220,9 +215,13 @@ impl serde::Serialize for UTCDate {
     }
 }
 
-impl SerializeInfallible for UTCDate {
-    fn serialize(&self) -> Vec<u8> {
-        (self.timestamp() as u64).serialize()
+impl<'de> serde::Deserialize<'de> for UTCDate {
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+    where
+        D: serde::Deserializer<'de>,
+    {
+        UTCDate::from_str(<&str>::deserialize(deserializer)?)
+            .map_err(|_| serde::de::Error::custom("invalid JMAP UTCDate"))
     }
 }
 
@@ -240,7 +239,8 @@ impl From<u64> for UTCDate {
 
 #[cfg(test)]
 mod tests {
-    use crate::{parser::json::Parser, types::date::UTCDate};
+    use crate::types::date::UTCDate;
+    use std::str::FromStr;
 
     #[test]
     fn parse_jmap_date() {
@@ -255,11 +255,7 @@ mod tests {
                 "2021-01-01T09:55:06+02:00",
             ),
         ] {
-            let date = Parser::new(format!("\"{input}\"").as_bytes())
-                .next_token::<UTCDate>()
-                .unwrap()
-                .unwrap_string("")
-                .unwrap();
+            let date = UTCDate::from_str(input).unwrap();
             assert_eq!(date.to_string(), expected_result);
 
             let timestamp = date.timestamp();
