@@ -4,53 +4,53 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use crate::changes::state::MessageCacheState;
+use crate::{
+    changes::state::MessageCacheState,
+    email::{PatchResult, handle_email_patch, ingested_into_object},
+};
 use common::{Server, auth::AccessToken};
 use email::{
     cache::{MessageCacheFetch, email::MessageCacheAccess, mailbox::MailboxCacheAccess},
-    message::copy::EmailCopy,
+    message::copy::{CopyMessageError, EmailCopy},
 };
 use http_proto::HttpSessionData;
 use jmap_proto::{
     error::set::SetError,
     method::{
-        copy::{CopyRequest, CopyResponse, RequestArguments},
-        set::{self, SetRequest},
+        copy::{CopyRequest, CopyResponse},
+        set::SetRequest,
     },
+    object::email::{Email, EmailProperty, EmailValue},
     request::{
-        Call, RequestMethod,
+        Call, IntoValid, MaybeInvalid, RequestMethod, SetRequestMethod,
         method::{MethodFunction, MethodName, MethodObject},
-        reference::MaybeReference,
-    },
-    response::references::EvalObjectReferences,
-    types::{
-        acl::Acl,
-        property::Property,
-        value::{MaybePatchValue, Value},
+        reference::MaybeResultReference,
     },
 };
+use jmap_tools::{Key, Value};
 use std::future::Future;
 use trc::AddContext;
+use types::acl::Acl;
 use utils::map::vec_map::VecMap;
 
 pub trait JmapEmailCopy: Sync + Send {
-    fn email_copy(
+    fn email_copy<'x>(
         &self,
-        request: CopyRequest<RequestArguments>,
+        request: CopyRequest<'x, Email>,
         access_token: &AccessToken,
-        next_call: &mut Option<Call<RequestMethod>>,
+        next_call: &mut Option<Call<RequestMethod<'x>>>,
         session: &HttpSessionData,
-    ) -> impl Future<Output = trc::Result<CopyResponse>> + Send;
+    ) -> impl Future<Output = trc::Result<CopyResponse<Email>>> + Send;
 }
 
 impl JmapEmailCopy for Server {
-    async fn email_copy(
+    async fn email_copy<'x>(
         &self,
-        request: CopyRequest<RequestArguments>,
+        request: CopyRequest<'x, Email>,
         access_token: &AccessToken,
-        next_call: &mut Option<Call<RequestMethod>>,
+        next_call: &mut Option<Call<RequestMethod<'x>>>,
         session: &HttpSessionData,
-    ) -> trc::Result<CopyResponse> {
+    ) -> trc::Result<CopyResponse<Email>> {
         let account_id = request.account_id.document_id();
         let from_account_id = request.from_account_id.document_id();
 
@@ -91,8 +91,7 @@ impl JmapEmailCopy for Server {
         // Obtain quota
         let resource_token = self.get_resource_token(access_token, account_id).await?;
 
-        'create: for (id, create) in request.create {
-            let id = id.unwrap();
+        'create: for (id, create) in request.create.into_valid() {
             let from_message_id = id.document_id();
             if !from_message_ids.contains(from_message_id) {
                 response.not_created.append(
@@ -109,64 +108,57 @@ impl JmapEmailCopy for Server {
             let mut keywords = Vec::new();
             let mut received_at = None;
 
-            for (property, value) in create.0 {
-                let value = match response.eval_object_references(value) {
-                    Ok(value) => value,
-                    Err(err) => {
-                        response.not_created.append(id, err);
-                        continue 'create;
-                    }
-                };
-
+            for (property, value) in create.into_expanded_object() {
                 match (property, value) {
-                    (Property::MailboxIds, MaybePatchValue::Value(Value::List(ids))) => {
+                    (Key::Property(EmailProperty::MailboxIds), Value::Object(ids)) => {
                         mailboxes = ids
-                            .into_iter()
-                            .filter_map(|id| id.try_unwrap_id()?.document_id().into())
+                            .into_expanded_boolean_set()
+                            .filter_map(|id| {
+                                id.try_into_property()?.try_into_id()?.document_id().into()
+                            })
                             .collect();
                     }
-
-                    (Property::MailboxIds, MaybePatchValue::Patch(patch)) => {
-                        let mut patch = patch.into_iter();
-                        if let Some(id) = patch.next().unwrap().try_unwrap_id() {
-                            let document_id = id.document_id();
-                            if patch.next().unwrap().try_unwrap_bool().unwrap_or_default() {
-                                if !mailboxes.contains(&document_id) {
-                                    mailboxes.push(document_id);
-                                }
-                            } else {
-                                mailboxes.retain(|id| id != &document_id);
-                            }
-                        }
-                    }
-
-                    (Property::Keywords, MaybePatchValue::Value(Value::List(keywords_))) => {
+                    (Key::Property(EmailProperty::Keywords), Value::Object(keywords_)) => {
                         keywords = keywords_
-                            .into_iter()
-                            .filter_map(|keyword| keyword.try_unwrap_keyword())
+                            .into_expanded_boolean_set()
+                            .filter_map(|id| id.try_into_property()?.try_into_keyword())
                             .collect();
                     }
-
-                    (Property::Keywords, MaybePatchValue::Patch(patch)) => {
-                        let mut patch = patch.into_iter();
-                        if let Some(keyword) = patch.next().unwrap().try_unwrap_keyword() {
-                            if patch.next().unwrap().try_unwrap_bool().unwrap_or_default() {
-                                if !keywords.contains(&keyword) {
-                                    keywords.push(keyword);
+                    (Key::Property(EmailProperty::Pointer(pointer)), value) => {
+                        match handle_email_patch(&pointer, value) {
+                            PatchResult::SetKeyword(keyword) => {
+                                if !keywords.contains(keyword) {
+                                    keywords.push(keyword.clone());
                                 }
-                            } else {
-                                keywords.retain(|k| k != &keyword);
+                            }
+                            PatchResult::RemoveKeyword(keyword) => {
+                                keywords.retain(|k| k != keyword);
+                            }
+                            PatchResult::AddMailbox(id) => {
+                                if !mailboxes.contains(&id) {
+                                    mailboxes.push(id);
+                                }
+                            }
+                            PatchResult::RemoveMailbox(id) => {
+                                mailboxes.retain(|mid| mid != &id);
+                            }
+                            PatchResult::Invalid(set_error) => {
+                                response.not_created.append(id, set_error);
+                                continue 'create;
                             }
                         }
                     }
-                    (Property::ReceivedAt, MaybePatchValue::Value(Value::Date(value))) => {
+                    (
+                        Key::Property(EmailProperty::ReceivedAt),
+                        Value::Element(EmailValue::Date(value)),
+                    ) => {
                         received_at = value.into();
                     }
                     (property, _) => {
                         response.not_created.append(
                             id,
                             SetError::invalid_properties()
-                                .with_property(property)
+                                .with_property(property.into_owned())
                                 .with_description("Invalid property or value.".to_string()),
                         );
                         continue 'create;
@@ -179,7 +171,7 @@ impl JmapEmailCopy for Server {
                 response.not_created.append(
                     id,
                     SetError::invalid_properties()
-                        .with_property(Property::MailboxIds)
+                        .with_property(EmailProperty::MailboxIds)
                         .with_description("Message has to belong to at least one mailbox."),
                 );
                 continue 'create;
@@ -191,7 +183,7 @@ impl JmapEmailCopy for Server {
                     response.not_created.append(
                         id,
                         SetError::invalid_properties()
-                            .with_property(Property::MailboxIds)
+                            .with_property(EmailProperty::MailboxIds)
                             .with_description(format!("mailboxId {mailbox_id} does not exist.")),
                     );
                     continue 'create;
@@ -214,22 +206,31 @@ impl JmapEmailCopy for Server {
                     &resource_token,
                     mailboxes,
                     keywords,
-                    received_at,
+                    received_at.map(|dt| dt.timestamp() as u64),
                     session.session_id,
                 )
                 .await?
             {
                 Ok(email) => {
-                    response.created.append(id, email.into());
+                    response
+                        .created
+                        .append(id, ingested_into_object(email).into());
                 }
                 Err(err) => {
-                    response.not_created.append(id, err);
+                    response.not_created.append(
+                        id,
+                        match err {
+                            CopyMessageError::NotFound => SetError::not_found()
+                                .with_description("Message not found not found in account."),
+                            CopyMessageError::OverQuota => SetError::over_quota(),
+                        },
+                    );
                 }
             }
 
             // Add to destroy list
             if on_success_delete {
-                destroy_ids.push(id);
+                destroy_ids.push(MaybeInvalid::Value(id));
             }
         }
 
@@ -243,14 +244,14 @@ impl JmapEmailCopy for Server {
             *next_call = Call {
                 id: String::new(),
                 name: MethodName::new(MethodObject::Email, MethodFunction::Set),
-                method: RequestMethod::Set(SetRequest {
+                method: RequestMethod::Set(SetRequestMethod::Email(SetRequest {
                     account_id: request.from_account_id,
                     if_in_state: request.destroy_from_if_in_state,
                     create: None,
                     update: None,
-                    destroy: MaybeReference::Value(destroy_ids).into(),
-                    arguments: set::RequestArguments::Email,
-                }),
+                    destroy: MaybeResultReference::Value(destroy_ids).into(),
+                    arguments: Default::default(),
+                })),
             }
             .into();
         }
