@@ -83,7 +83,7 @@ pub fn ece_encrypt(
     // Split into records
     let rs = ECE_WEBPUSH_DEFAULT_RS as usize - ECE_TAG_LENGTH;
     let mut min_num_records = data.len() / (rs - 1);
-    if data.len() % (rs - 1) != 0 {
+    if !data.len().is_multiple_of(rs - 1) {
         min_num_records += 1;
     }
     let mut pad_length = std::cmp::max(pad_length, min_num_records);
@@ -123,7 +123,7 @@ pub fn ece_encrypt(
             data_share = data.len();
         } else if extra_data > 0 {
             let mut extra_share = extra_data / (records_remaining - 1);
-            if extra_data % (records_remaining - 1) != 0 {
+            if !extra_data.is_multiple_of(records_remaining - 1) {
                 extra_share += 1;
             }
             data_share += extra_share;
