@@ -4,25 +4,24 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
+use crate::{
+    core::{Session, SessionAddress},
+    scripts::ScriptResult,
+};
 use common::{
     KV_GREYLIST, config::smtp::session::Stage, listener::SessionStream, scripts::ScriptModification,
 };
-
 use directory::backend::RcptType;
 use smtp_proto::{
     RCPT_NOTIFY_DELAY, RCPT_NOTIFY_FAILURE, RCPT_NOTIFY_NEVER, RCPT_NOTIFY_SUCCESS, RcptTo,
 };
+use std::borrow::Cow;
 use store::dispatch::lookup::KeyValue;
 use trc::{SecurityEvent, SmtpEvent};
-
-use crate::{
-    core::{Session, SessionAddress},
-    queue::DomainPart,
-    scripts::ScriptResult,
-};
+use utils::DomainPart;
 
 impl<T: SessionStream> Session<T> {
-    pub async fn handle_rcpt_to(&mut self, to: RcptTo<String>) -> Result<(), ()> {
+    pub async fn handle_rcpt_to(&mut self, to: RcptTo<Cow<'_, str>>) -> Result<(), ()> {
         #[cfg(feature = "test_mode")]
         if self.instance.id.ends_with("-debug") {
             if to.address.contains("fail@") {
@@ -72,9 +71,9 @@ impl<T: SessionStream> Session<T> {
         let rcpt = SessionAddress {
             domain: address_lcase.domain_part().into(),
             address_lcase,
-            address: to.address,
+            address: to.address.into_owned(),
             flags: to.flags,
-            dsn_info: to.orcpt,
+            dsn_info: to.orcpt.map(|e| e.into_owned()),
         };
 
         if self.data.rcpt_to.contains(&rcpt) {
