@@ -4,25 +4,24 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
+use self::assert::AssertValue;
+use crate::backend::MAX_TOKEN_LENGTH;
+use log::ChangeLogBuilder;
+use nlp::tokenizers::word::WordTokenizer;
+use rkyv::util::AlignedVec;
 use std::{
     collections::HashSet,
     time::{Duration, SystemTime},
 };
-
-use log::ChangeLogBuilder;
-use nlp::tokenizers::word::WordTokenizer;
-use rkyv::util::AlignedVec;
-use utils::{
-    BlobHash,
-    map::{
-        bitmap::{Bitmap, ShortId},
-        vec_map::VecMap,
+use types::{
+    blob_hash::BlobHash,
+    collection::{Collection, SyncCollection, VanishedCollection},
+    field::{
+        CalendarField, ContactField, EmailField, EmailSubmissionField, Field, MailboxField,
+        PrincipalField, SieveField,
     },
 };
-
-use crate::{BlobClass, backend::MAX_TOKEN_LENGTH};
-
-use self::assert::AssertValue;
+use utils::map::{bitmap::Bitmap, vec_map::VecMap};
 
 pub mod assert;
 pub mod batch;
@@ -105,7 +104,7 @@ pub struct Batch<'x> {
 #[derive(Debug)]
 pub struct BatchBuilder {
     current_account_id: Option<u32>,
-    current_collection: Option<u8>,
+    current_collection: Option<Collection>,
     current_document_id: Option<u32>,
     changes: VecMap<u32, ChangeLogBuilder>,
     changed_collections: VecMap<u32, ChangedCollection>,
@@ -118,8 +117,8 @@ pub struct BatchBuilder {
 
 #[derive(Debug, Default)]
 pub struct ChangedCollection {
-    pub changed_containers: Bitmap<ShortId>,
-    pub changed_items: Bitmap<ShortId>,
+    pub changed_containers: Bitmap<SyncCollection>,
+    pub changed_items: Bitmap<SyncCollection>,
 }
 
 #[derive(Debug, PartialEq, Eq, Hash)]
@@ -128,7 +127,7 @@ pub enum Operation {
         account_id: u32,
     },
     Collection {
-        collection: u8,
+        collection: Collection,
     },
     DocumentId {
         document_id: u32,
@@ -151,11 +150,17 @@ pub enum Operation {
         set: bool,
     },
     Log {
-        collection: u8,
+        collection: LogCollection,
         set: Vec<u8>,
     },
 }
 
+#[derive(Debug, PartialEq, Eq, Hash, Clone, Copy)]
+pub enum LogCollection {
+    Sync(SyncCollection),
+    Vanished(VanishedCollection),
+}
+
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub enum BitmapClass {
     DocumentIds,
@@ -405,29 +410,6 @@ impl BitmapClass {
     }
 }
 
-impl AsRef<BlobClass> for BlobClass {
-    fn as_ref(&self) -> &BlobClass {
-        self
-    }
-}
-
-impl BlobClass {
-    pub fn account_id(&self) -> u32 {
-        match self {
-            BlobClass::Reserved { account_id, .. } | BlobClass::Linked { account_id, .. } => {
-                *account_id
-            }
-        }
-    }
-
-    pub fn is_valid(&self) -> bool {
-        match self {
-            BlobClass::Reserved { expires, .. } => *expires > now(),
-            BlobClass::Linked { .. } => true,
-        }
-    }
-}
-
 impl AssignedIds {
     pub fn push_counter_id(&mut self, id: i64) {
         self.ids.push(AssignedId::Counter(id));
@@ -515,6 +497,15 @@ impl ArchiveVersion {
     }
 }
 
+impl From<LogCollection> for u8 {
+    fn from(value: LogCollection) -> Self {
+        match value {
+            LogCollection::Sync(col) => col as u8,
+            LogCollection::Vanished(col) => col as u8,
+        }
+    }
+}
+
 impl std::fmt::Debug for MergeFn {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("MergeFn")
@@ -536,3 +527,51 @@ impl std::hash::Hash for MergeFn {
         self.fnc_id.hash(state);
     }
 }
+
+impl From<ContactField> for ValueClass {
+    fn from(value: ContactField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<CalendarField> for ValueClass {
+    fn from(value: CalendarField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<EmailField> for ValueClass {
+    fn from(value: EmailField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<MailboxField> for ValueClass {
+    fn from(value: MailboxField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<PrincipalField> for ValueClass {
+    fn from(value: PrincipalField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<SieveField> for ValueClass {
+    fn from(value: SieveField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<EmailSubmissionField> for ValueClass {
+    fn from(value: EmailSubmissionField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<Field> for ValueClass {
+    fn from(value: Field) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
