@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
@@ -139,6 +139,7 @@ pub enum Key {
     ValidTo,
     Value,
     Version,
+    QueueName,
 }
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
@@ -236,9 +237,8 @@ pub enum HousekeeperEvent {
 
 #[event_type]
 pub enum TaskQueueEvent {
-    Index,
-    BayesTrain,
-    Locked,
+    TaskAcquired,
+    TaskLocked,
     BlobNotFound,
     MetadataNotFound,
 }
@@ -352,7 +352,7 @@ pub enum SmtpEvent {
     ConnectionStart,
     ConnectionEnd,
     Error,
-    RemoteIdNotFound,
+    IdNotFound,
     ConcurrencyLimitExceeded,
     TransferLimitExceeded,
     RateLimitExceeded,
@@ -608,6 +608,7 @@ pub enum SpamEvent {
     TrainError,
     Classify,
     ClassifyError,
+    TrainAccount,
 }
 
 #[event_type]
@@ -870,6 +871,7 @@ pub enum MessageIngestEvent {
     JmapAppend,
     Duplicate,
     Error,
+    FtsIndex,
 }
 
 #[event_type]
@@ -983,6 +985,13 @@ pub enum WebDavEvent {
 #[event_type]
 pub enum CalendarEvent {
     RuleExpansionError,
+    AlarmSent,
+    AlarmSkipped,
+    AlarmRecipientOverride,
+    AlarmFailed,
+    ItipMessageSent,
+    ItipMessageReceived,
+    ItipMessageError,
 }
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
