@@ -4,6 +4,10 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
+use crate::{
+    directory::internal::TestInternalDirectory,
+    jmap::{assert_is_empty, mailbox::destroy_all_mailboxes, test_account_login},
+};
 use ::email::mailbox::{INBOX_ID, TRASH_ID};
 use jmap_client::{
     core::{
@@ -14,14 +18,9 @@ use jmap_client::{
     mailbox::{self, Role},
     principal::ACL,
 };
-use jmap_proto::types::id::Id;
 use std::fmt::Debug;
 use store::ahash::AHashMap;
-
-use crate::{
-    directory::internal::TestInternalDirectory,
-    jmap::{assert_is_empty, mailbox::destroy_all_mailboxes, test_account_login},
-};
+use types::id::Id;
 
 use super::JMAPTest;
 
@@ -173,7 +172,7 @@ pub async fn test(params: &mut JMAPTest) {
 
     // Jane grants Inbox ReadItems access to John
     jane_client
-        .mailbox_update_acl(&inbox_id, "jdoe@example.com", [ACL::ReadItems])
+        .mailbox_update_acl(&inbox_id, &john_id.to_string(), [ACL::ReadItems])
         .await
         .unwrap();
 
@@ -257,15 +256,9 @@ pub async fn test(params: &mut JMAPTest) {
             .await,
     );
 
-    // John only has ReadItems access to Inbox but no Read access
-    assert_forbidden(
-        john_client
-            .set_default_account_id(jane_id.to_string())
-            .mailbox_get(&inbox_id, [mailbox::Property::MyRights].into())
-            .await,
-    );
+    // John only has ReadItems access to Inbox
     jane_client
-        .mailbox_update_acl(&inbox_id, "jdoe@example.com", [ACL::Read, ACL::ReadItems])
+        .mailbox_update_acl(&inbox_id, &john_id.to_string(), [ACL::ReadItems])
         .await
         .unwrap();
     assert_eq!(
@@ -332,8 +325,8 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &inbox_id,
-            "jdoe@example.com",
-            [ACL::Read, ACL::ReadItems, ACL::AddItems],
+            &john_id.to_string(),
+            [ACL::ReadItems, ACL::AddItems],
         )
         .await
         .unwrap();
@@ -397,8 +390,8 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &inbox_id,
-            "jdoe@example.com",
-            [ACL::Read, ACL::ReadItems, ACL::AddItems, ACL::RemoveItems],
+            &john_id.to_string(),
+            [ACL::ReadItems, ACL::AddItems, ACL::RemoveItems],
         )
         .await
         .unwrap();
@@ -418,13 +411,12 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &inbox_id,
-            "jdoe@example.com",
+            &john_id.to_string(),
             [
-                ACL::Read,
                 ACL::ReadItems,
                 ACL::AddItems,
                 ACL::RemoveItems,
-                ACL::ModifyItems,
+                ACL::SetKeywords,
             ],
         )
         .await
@@ -450,13 +442,12 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &inbox_id,
-            "jdoe@example.com",
+            &john_id.to_string(),
             [
-                ACL::Read,
                 ACL::ReadItems,
                 ACL::AddItems,
                 ACL::RemoveItems,
-                ACL::ModifyItems,
+                ACL::SetKeywords,
                 ACL::CreateChild,
             ],
         )
@@ -479,8 +470,8 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &mailbox_id,
-            "jdoe@example.com",
-            [ACL::Read, ACL::ReadItems, ACL::Modify],
+            &john_id.to_string(),
+            [ACL::ReadItems, ACL::Rename],
         )
         .await
         .unwrap();
@@ -500,8 +491,8 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &mailbox_id,
-            "jdoe@example.com",
-            [ACL::Read, ACL::ReadItems, ACL::Modify, ACL::AddItems],
+            &john_id.to_string(),
+            [ACL::ReadItems, ACL::Rename, ACL::AddItems],
         )
         .await
         .unwrap();
@@ -521,14 +512,8 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &mailbox_id,
-            "jdoe@example.com",
-            [
-                ACL::Read,
-                ACL::ReadItems,
-                ACL::Modify,
-                ACL::AddItems,
-                ACL::Delete,
-            ],
+            &john_id.to_string(),
+            [ACL::ReadItems, ACL::Rename, ACL::AddItems, ACL::Delete],
         )
         .await
         .unwrap();
@@ -541,11 +526,10 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &mailbox_id,
-            "jdoe@example.com",
+            &john_id.to_string(),
             [
-                ACL::Read,
                 ACL::ReadItems,
-                ACL::Modify,
+                ACL::Rename,
                 ACL::AddItems,
                 ACL::Delete,
                 ACL::RemoveItems,
@@ -563,7 +547,7 @@ pub async fn test(params: &mut JMAPTest) {
     assert_forbidden(
         john_client
             .set_default_account_id(jane_id.to_string())
-            .mailbox_update_acl(&inbox_id, "bill@example.com", [ACL::Read, ACL::ReadItems])
+            .mailbox_update_acl(&inbox_id, &bill_id.to_string(), [ACL::ReadItems])
             .await,
     );
     assert_forbidden(
@@ -575,15 +559,14 @@ pub async fn test(params: &mut JMAPTest) {
     jane_client
         .mailbox_update_acl(
             &inbox_id,
-            "jdoe@example.com",
+            &john_id.to_string(),
             [
-                ACL::Read,
                 ACL::ReadItems,
                 ACL::AddItems,
                 ACL::RemoveItems,
-                ACL::ModifyItems,
+                ACL::SetKeywords,
                 ACL::CreateChild,
-                ACL::Modify,
+                ACL::Rename,
                 ACL::Administer,
             ],
         )
@@ -603,14 +586,15 @@ pub async fn test(params: &mut JMAPTest) {
             ACL::ReadItems,
             ACL::AddItems,
             ACL::RemoveItems,
-            ACL::ModifyItems,
+            ACL::SetSeen,
+            ACL::SetKeywords,
             ACL::CreateChild,
-            ACL::Modify
+            ACL::Rename
         ]
     );
     john_client
         .set_default_account_id(jane_id.to_string())
-        .mailbox_update_acl(&inbox_id, "bill@example.com", [ACL::Read, ACL::ReadItems])
+        .mailbox_update_acl(&inbox_id, &bill_id.to_string(), [ACL::ReadItems])
         .await
         .unwrap();
     assert_eq!(
@@ -631,7 +615,7 @@ pub async fn test(params: &mut JMAPTest) {
 
     // Revoke all access to John
     jane_client
-        .mailbox_update_acl(&inbox_id, "jdoe@example.com", [])
+        .mailbox_update_acl(&inbox_id, &john_id.to_string(), [])
         .await
         .unwrap();
     assert_forbidden(
