@@ -4,16 +4,13 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use std::{fs, path::PathBuf};
-
+use super::JMAPTest;
+use crate::jmap::{assert_is_empty, mailbox::destroy_all_mailboxes, replace_blob_ids};
 use ::email::mailbox::INBOX_ID;
 use jmap_client::email::{self, Header, HeaderForm, import::EmailImportResponse};
-use jmap_proto::types::id::Id;
 use mail_parser::HeaderName;
-
-use crate::jmap::{assert_is_empty, mailbox::destroy_all_mailboxes, replace_blob_ids};
-
-use super::JMAPTest;
+use std::{fs, path::PathBuf};
+use types::id::Id;
 
 pub async fn test(params: &mut JMAPTest) {
     println!("Running Email Get tests...");
