@@ -17,7 +17,7 @@ use email::mailbox::INBOX_ID;
 use futures::StreamExt;
 
 use jmap_client::{TypeState, event_source::Changes, mailbox::Role};
-use jmap_proto::types::id::Id;
+use types::id::Id;
 use store::ahash::AHashSet;
 
 use tokio::sync::mpsc;
