@@ -4,24 +4,21 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use std::{io::Cursor, time::Duration};
-
+use super::JMAPTest;
 use crate::{
     jmap::{assert_is_empty, mailbox::destroy_all_mailboxes},
     store::deflate_test_resource,
 };
-use common::auth::AccessToken;
-
 use ::email::message::ingest::{EmailIngest, IngestEmail, IngestSource};
+use common::auth::AccessToken;
 use jmap_client::{email, mailbox::Role};
-use jmap_proto::types::{collection::Collection, id::Id};
 use mail_parser::{MessageParser, mailbox::mbox::MessageIterator};
+use std::{io::Cursor, str::FromStr, time::Duration};
 use store::{
     ahash::{AHashMap, AHashSet},
     rand::{self, Rng},
 };
-
-use super::JMAPTest;
+use types::{collection::Collection, id::Id};
 
 pub async fn test(params: &mut JMAPTest) {
     test_single_thread(params).await;
@@ -162,7 +159,7 @@ async fn test_single_thread(params: &mut JMAPTest) {
             let thread_ids: AHashSet<u32> = result
                 .ids()
                 .iter()
-                .map(|id| Id::from_bytes(id.as_bytes()).unwrap().prefix_id())
+                .map(|id| Id::from_str(id).unwrap().prefix_id())
                 .collect();
 
             assert_eq!(
@@ -215,7 +212,7 @@ async fn test_multi_thread(params: &mut JMAPTest) {
     //let semaphore = sync::Arc::Arc::new(tokio::sync::Semaphore::new(100));
     let mut handles = vec![];
 
-    let mailbox_id = Id::from_bytes(
+    let mailbox_id = Id::from_str(
         params
             .client
             .set_default_account_id(Id::new(0u64).to_string())
@@ -223,8 +220,7 @@ async fn test_multi_thread(params: &mut JMAPTest) {
             .await
             .unwrap()
             .id()
-            .unwrap()
-            .as_bytes(),
+            .unwrap(),
     )
     .unwrap()
     .document_id();
