@@ -7,10 +7,6 @@
 use crate::store::TempDir;
 use ahash::AHashSet;
 use common::{Core, manager::backup::BackupParams};
-use jmap_proto::types::{
-    collection::{Collection, SyncCollection},
-    property::Property,
-};
 use store::{
     rand,
     write::{
@@ -19,7 +15,11 @@ use store::{
     },
     *,
 };
-use utils::BlobHash;
+use types::{
+    blob_hash::BlobHash,
+    collection::{Collection, SyncCollection},
+    field::{Field, MailboxField},
+};
 
 pub async fn test(db: Store) {
     let mut core = Core::default();
@@ -55,20 +55,25 @@ pub async fn test(db: Store) {
         batch.with_account_id(account_id);
 
         // Create properties of different sizes
-        for collection in [0, 1, 2, 3] {
+        for collection in [
+            Collection::Email,
+            Collection::Mailbox,
+            Collection::Thread,
+            Collection::Identity,
+        ] {
             batch.with_collection(collection);
 
             for document_id in [0, 10, 20, 30, 40] {
                 batch.create_document(document_id);
 
-                if collection == u8::from(Collection::Mailbox) {
+                if collection == Collection::Mailbox {
                     batch
                         .set(
-                            ValueClass::Property(Property::Value.into()),
+                            ValueClass::Property(Field::ARCHIVE.into()),
                             random_bytes(10),
                         )
                         .add(
-                            ValueClass::Property(Property::EmailIds.into()),
+                            ValueClass::Property(MailboxField::UidCounter.into()),
                             rand::random(),
                         );
                 }
