@@ -4,15 +4,14 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use std::collections::HashSet;
-
 use ahash::AHashSet;
-use jmap_proto::types::collection::SyncCollection;
+use std::collections::HashSet;
 use store::{
     Store, ValueKey,
     rand::{self, Rng},
     write::{AlignedBytes, Archive, Archiver, BatchBuilder, DirectoryClass, ValueClass},
 };
+use types::collection::{Collection, SyncCollection};
 
 // FDB max value
 const MAX_VALUE_SIZE: usize = 100000;
@@ -20,13 +19,15 @@ const MAX_VALUE_SIZE: usize = 100000;
 pub async fn test(db: Store) {
     #[cfg(feature = "foundationdb")]
     if matches!(db, Store::FoundationDb(_)) && std::env::var("SLOW_FDB_TRX").is_ok() {
+        use types::collection::Collection;
+
         println!("Running slow FoundationDB transaction tests...");
 
         // Create 900000 keys
         let mut batch = BatchBuilder::new();
         batch
             .with_account_id(0)
-            .with_collection(0)
+            .with_collection(Collection::Email)
             .update_document(0);
         for n in 0..900000 {
             batch.set(
@@ -39,7 +40,7 @@ pub async fn test(db: Store) {
                 batch = BatchBuilder::new();
                 batch
                     .with_account_id(0)
-                    .with_collection(0)
+                    .with_collection(Collection::Email)
                     .update_document(0);
             }
         }
@@ -81,7 +82,7 @@ pub async fn test(db: Store) {
         let mut batch = BatchBuilder::new();
         batch
             .with_account_id(0)
-            .with_collection(0)
+            .with_collection(Collection::Email)
             .update_document(0);
         for n in 0..900000 {
             batch.clear(ValueClass::Config(format!("key{n:10}").into_bytes()));
@@ -91,7 +92,7 @@ pub async fn test(db: Store) {
                 batch = BatchBuilder::new();
                 batch
                     .with_account_id(0)
-                    .with_collection(0)
+                    .with_collection(Collection::Email)
                     .update_document(0);
             }
         }
@@ -108,7 +109,7 @@ pub async fn test(db: Store) {
                 let mut builder = BatchBuilder::new();
                 builder
                     .with_account_id(0)
-                    .with_collection(0)
+                    .with_collection(Collection::Email)
                     .update_document(0)
                     .merge(ValueClass::Property(3), |bytes| {
                         if let Some(bytes) = bytes {
@@ -152,7 +153,7 @@ pub async fn test(db: Store) {
                 let mut builder = BatchBuilder::new();
                 builder
                     .with_account_id(0)
-                    .with_collection(0)
+                    .with_collection(Collection::Email)
                     .update_document(0)
                     .add_and_get(ValueClass::Directory(DirectoryClass::UsedQuota(0)), 1);
                 db.write(builder.build_all())
@@ -206,7 +207,7 @@ pub async fn test(db: Store) {
 
                 builder
                     .with_account_id(0)
-                    .with_collection(0)
+                    .with_collection(Collection::Email)
                     .update_document(document_id)
                     .set_versioned(ValueClass::Property(5), archived_value, offset)
                     .log_container_insert(SyncCollection::Email);
@@ -271,7 +272,7 @@ pub async fn test(db: Store) {
         db.write(
             BatchBuilder::new()
                 .with_account_id(0)
-                .with_collection(0)
+                .with_collection(Collection::Email)
                 .update_document(0)
                 .set(ValueClass::Property(1), value.as_slice())
                 .set(ValueClass::Property(0), "check1".as_bytes())
@@ -300,7 +301,7 @@ pub async fn test(db: Store) {
         db.write(
             BatchBuilder::new()
                 .with_account_id(0)
-                .with_collection(0)
+                .with_collection(Collection::Email)
                 .update_document(0)
                 .clear(ValueClass::Property(1))
                 .build_all(),
@@ -343,7 +344,7 @@ pub async fn test(db: Store) {
         let mut batch = BatchBuilder::new();
         batch
             .with_account_id(0)
-            .with_collection(0)
+            .with_collection(Collection::Email)
             .with_account_id(0)
             .update_document(0)
             .clear(ValueClass::Property(0))
